==> alfred_osint-0.2.3b2-py3-none-any.whl: alfred_osint/lang/il.py <==
# il.py
# Hebrew

encrypt1 = "מצפין מפתח..."

title1 = "תודה רבה לשותפים שלנו!"

disclamer = " הצהרת שחרור: לא כל האתרים או ה-Proxys מתוכננים לעבוד! \n על ידי השימוש אתה לוקח בחשבון את הפעולות שלך"

targetusernames = "שמות המשתמש של היעד: "

version = "גרסה"

config1 = "קובץ תצורה יוצא "
config2 = "עדכן קובץ יוצא "
config3 = "תיקייה כבר קיימת: "
config4 = "חפש עדכונים? [Y/n]: ⤷ "
config5 = "ערוך את התצורה? [Y/n]: ⤷ "
config6 = "מה אתה רוצה לשנות? ⤷ "
config7 = "יוצר תיקייה: "
config8 = "התיקייה כבר קיימת: "

configOption1 = "[1] בדוק אם קיימים עדכונים: "
configOption2 = "[2] הצג טיפים: "
configOption3 = "[3] נתיב הורדת אתר: "
configOption4 = "[4] דפדפן: "
configOption5 = "[5] שפה: "
configOption6 = "[6] ColorScheme: "
configOptionA = "[A] נקה את אלפרד. (זה מסיר קבצים זמניים)"
configOptionB = "[B] כלים למפתחים."

configOption1Message = "בסדר! [בדוק לעדכונים] מוגדר ל-כן. משתנה ל-No"
configOption2Message = "אוקי! [showtips] מוגדר ל-כן. משתנה ל-No"
configOption3Message = "נתיב חדש: ⤷ "
configOption4Message = """סוגים נתמכים:
                          פיירפוקס
                          קָצֶה
                          כרום
                          """
configOption5Message = """
             אנא הזן את קוד השפה שלך
             שפה נתמכת:
                 it = איטלקית
                 en = אנגלית
                 il = עברית
                 es = ספרדית
                 fr = צרפתית 
                 ar = ערבית 
                 de = גרמנית
                 ru = רוסית
                 hi = הינדית
                 """
configOptionAMessage = "בוצע!"
configOptionBMessage = "ברוכים הבאים לתפריט המפתחים!"

configOption1Message2 = "בסדר! [בדוק עבור עדכונים] מוגדר ל-No. משתנה ל-כן"
configOption2Message2 = "בסדר! [showtips] מוגדר ל-No. משתנה ל-כן"
configOptionBMessage2 = "אל תיתן את המפתחות הבאים לכל אחד מלבד מפתח אלפרד."
configOptionBMessage3 = "מפתח פרטי: "
configOptionBMessage4 = "syscrypt: "

target = "יעד: ⤷ "
browser = "דפדפן:"

file_not_found = "הקובץ לא נמצא: {filename}"
permission_denied = "הרשאה נדחתה עבור {operation} ב-{path}"

note = "הערה!"
path = "נתיב: ⤷ "
warning1 = "אתרים רבים אינם מאפשרים הורדת קובצי האתר שלהם. השימוש באחריותך האישית."
warning2 = " השימוש ב-Webscraper הוא די איטי."
warning3 = (
    "זו ההשקה הראשונה שלך :D אולי תצטרך להפעיל מחדש את אלפרד כדי להשתמש בכל המודולים"
)
warning4 = " אתה משתמש במהדורה מוקדמת של אלפרד!"
warning5 = "הזן יעד לפני שתמשיך: "

confirm1 = "רוצה להוריד תמונות/סרטונים? [Y/n] ⤷ "
confirm2 = "רוץ שוב?: [Y/n] ⤷ "

prompt1 = "היכנס שוב לאתר: ⤷ "
prompt2 = "אנא דווח על כל באג או שגיאה לשרת ה-Repo או Discord שלנו."
prompt3 = "תוכל לבטל את העדכון בקובץ התצורה"
prompt4 = "הצטרף לדיסקורד שלנו: https://discord.gg/xrdjxyuSQt "
prompt5 = "בסדר! אני אשאל מאוחר יותר...."
prompt6 = "אתרים לא עובדים..."

download1 = "מורידה"
updates = "עדכונים מופעלים!"


idk1 = "לא בטוח למה התכוונת...."
idk2 = "לא בטוח למה התכוונת. אני אשאל מאוחר יותר"
idk3 = "לא בטוח... אבל אתה יכול לבדוק כאן: "
scan1 = "מחפש אתרים עם: "

status1 = "עובד...."
status2 = "יצירת/החלפת קובץ שמירה."
status3 = "מתקין מחדש............"
status4 = "חוזר לאלפרד בקרוב..."
status5 = "בודק...."
status6 = "עוצר..... נשמר ב-captured/working.txt"
status7 = "עצור........"

save1 = "תוצאות שמורות ב"
save2 = "תוצאות שמורות לקובץ"

error1 = "שגיאת הרשאה"
error2 = "שגיאת הקלדה"
error3 = "לא מוצא את קובץ השמירה!"
error4 = "הספרייה לא קיימת."
error5 = "לא מוצא את הקבצים הדרושים. מנסה להתקין מחדש את אלפרד"
error6 = (
    "אה הו שגיאה! נראה שהחיבור לא עובד. בדוק את החיבור או ה-Proxy שלך, ואז נסה שוב :"
)
error7 = "לא מוצא את קובץ האתר"
error8 = "שגיאה בהורדת תוכן אינטרנט!"
error9 = "שגיאה בקובץ האתר"
error10 = "בחירת מנהלי אינטרנט לא חוקית."
error11 = "אירעה שגיאה: "

fileshare1 = "[*] מאזין כמו"
fileshare2 = "מחובר."
fileshare3 = "מקבל"

wikiOption1 = "[1] התקנה"
wikiOption2 = "[2] אפשרויות"
wikiOption3 = "[3] שגיאות"
wikiOption4 = "[4] אלפרד האפל"
wikiOption5 = "[5] מודולים"

wikilist = "תוכל למצוא מידע על זה כאן: "

rqUname = "שם משתמש מבוקש: "

sender1 = "[+] מתחבר ל"
sender2 = "[+] מחובר."
sender3 = "שולח."
sender4 = "קובץ לשליחה: ⤷ "

fs1 = "שרת מארח? [Y/N]: ⤷ "
fs2 = "ממתין להתחבר למארח!"
fs3 = "מחכה שהלקוח יתחבר!"

siteDl1 = " סהכ קבצי סקריפט בדף:"
siteDl2 = "סהכ קבצי CSS בדף:"
# דוגמה לפני הספירה אימא לשכוח
# הודעות ייבוא

# print(messages.title) # פלט: שלום, עולם!
# print(messages.text1) # פלט: זוהי הודעה לדוגמה.

# # דוגמה לשימוש במצייני מיקום בהודעות
# filename = "example.txt"
# print(messages.file_not_found.format(filename=filename))

==> alfred_osint-0.2.3.1-py3-none-any.whl: alfred_osint/lang/il.py <==
# il.py
# Hebrew

encrypt1 = "מצפין מפתח..."

title1 = "תודה רבה לשותפים שלנו!"

disclamer = " הצהרת שחרור: לא כל האתרים או ה-Proxys מתוכננים לעבוד! \n על ידי השימוש אתה לוקח בחשבון את הפעולות שלך"

targetusernames = "שמות המשתמש של היעד: "

version = "גרסה"

config1 = "קובץ תצורה יוצא "
config2 = "עדכן קובץ יוצא "
config3 = "תיקייה כבר קיימת: "
config4 = "חפש עדכונים? [Y/n]: ⤷ "
config5 = "ערוך את התצורה? [Y/n]: ⤷ "
config6 = "מה אתה רוצה לשנות? ⤷ "
config7 = "יוצר תיקייה: "
config8 = "התיקייה כבר קיימת: "

configOption1 = "[1] בדוק אם קיימים עדכונים: "
configOption2 = "[2] הצג טיפים: "
configOption3 = "[3] נתיב הורדת אתר: "
configOption4 = "[4] דפדפן: "
configOption5 = "[5] שפה: "
configOptionA = "[A] נקה את אלפרד. (זה מסיר קבצים זמניים)"
configOptionB = "[B] כלים למפתחים."

configOption1Message = "בסדר! [בדוק לעדכונים] מוגדר ל-כן. משתנה ל-No"
configOption2Message = "אוקי! [showtips] מוגדר ל-כן. משתנה ל-No"
configOption3Message = "נתיב חדש: ⤷ "
configOption4Message = """סוגים נתמכים:
                          פיירפוקס
                          קָצֶה
                          כרום
                          """
configOption5Message = """
             אנא הזן את קוד השפה שלך
             שפה נתמכת:
                 it = איטלקית
                 en = אנגלית
                 il = עברית
                 es = ספרדית
                 fr = צרפתית 
                 ar = ערבית 
                 de = גרמנית                               """
configOptionAMessage = "בוצע!"
configOptionBMessage = "ברוכים הבאים לתפריט המפתחים!"

configOption1Message2 = "בסדר! [בדוק עבור עדכונים] מוגדר ל-No. משתנה ל-כן"
configOption2Message2 = "בסדר! [showtips] מוגדר ל-No. משתנה ל-כן"
configOptionBMessage2 = "אל תיתן את המפתחות הבאים לכל אחד מלבד מפתח אלפרד."
configOptionBMessage3 = "מפתח פרטי: "
configOptionBMessage4 = "syscrypt: "

target = "יעד: ⤷ "
browser = "דפדפן:"

file_not_found = "הקובץ לא נמצא: {filename}"
permission_denied = "הרשאה נדחתה עבור {operation} ב-{path}"

note = "הערה!"
path = "נתיב: ⤷ "
warning1 = "אתרים רבים אינם מאפשרים הורדת קובצי האתר שלהם. השימוש באחריותך האישית."
warning2 = " השימוש ב-Webscraper הוא די איטי."
warning3 = (
    "זו ההשקה הראשונה שלך :D אולי תצטרך להפעיל מחדש את אלפרד כדי להשתמש בכל המודולים"
)
warning4 = " אתה משתמש במהדורה מוקדמת של אלפרד!"

confirm1 = "רוצה להוריד תמונות/סרטונים? [Y/n] ⤷ "
confirm2 = "רוץ שוב?: [Y/n] ⤷ "

prompt1 = "היכנס שוב לאתר: ⤷ "
prompt2 = "אנא דווח על כל באג או שגיאה לשרת ה-Repo או Discord שלנו."
prompt3 = "תוכל לבטל את העדכון בקובץ התצורה"
prompt4 = "הצטרף לדיסקורד שלנו: https://discord.gg/xrdjxyuSQt "
prompt5 = "בסדר! אני אשאל מאוחר יותר...."
prompt6 = "אתרים לא עובדים..."

download1 = "מורידה"
updates = "עדכונים מופעלים!"


idk1 = "לא בטוח למה התכוונת...."
idk2 = "לא בטוח למה התכוונת. אני אשאל מאוחר יותר"
idk3 = "לא בטוח... אבל אתה יכול לבדוק כאן: "
scan1 = "מחפש אתרים עם: "

status1 = "עובד...."
status2 = "יצירת/החלפת קובץ שמירה."
status3 = "מתקין מחדש............"
status4 = "חוזר לאלפרד בקרוב..."
status5 = "בודק...."
status6 = "עוצר..... נשמר ב-captured/working.txt"
status7 = "עצור........"

save1 = "תוצאות שמורות ב"
save2 = "תוצאות שמורות לקובץ"

error1 = "שגיאת הרשאה"
error2 = "שגיאת הקלדה"
error3 = "לא מוצא את קובץ השמירה!"
error4 = "הספרייה לא קיימת."
error5 = "לא מוצא את הקבצים הדרושים. מנסה להתקין מחדש את אלפרד"
error6 = (
    "אה הו שגיאה! נראה שהחיבור לא עובד. בדוק את החיבור או ה-Proxy שלך, ואז נסה שוב :"
)
error7 = "לא מוצא את קובץ האתר"
error8 = "שגיאה בהורדת תוכן אינטרנט!"
error9 = "שגיאה בקובץ האתר"
error10 = "בחירת מנהלי אינטרנט לא חוקית."
error11 = "אירעה שגיאה: "

fileshare1 = "[*] מאזין כמו"
fileshare2 = "מחובר."
fileshare3 = "מקבל"

wikiOption1 = "[1] התקנה"
wikiOption2 = "[2] אפשרויות"
wikiOption3 = "[3] שגיאות"
wikiOption4 = "[4] אלפרד האפל"
wikiOption5 = "[5] מודולים"

wikilist = "תוכל למצוא מידע על זה כאן: "

rqUname = "שם משתמש מבוקש: "

sender1 = "[+] מתחבר ל"
sender2 = "[+] מחובר."
sender3 = "שולח."
sender4 = "קובץ לשליחה: ⤷ "

fs1 = "שרת מארח? [Y/N]: ⤷ "
fs2 = "ממתין להתחבר למארח!"
fs3 = "מחכה שהלקוח יתחבר!"

siteDl1 = " סהכ קבצי סקריפט בדף:"
siteDl2 = "סהכ קבצי CSS בדף:"
# דוגמה לפני הספירה אימא לשכוח
# הודעות ייבוא

# print(messages.title) # פלט: שלום, עולם!
# print(messages.text1) # פלט: זוהי הודעה לדוגמה.

# # דוגמה לשימוש במצייני מיקום בהודעות
# filename = "example.txt"
# print(messages.file_not_found.format(filename=filename))
